package kieker.webgui.common;

import junit.framework.Assert;
import junit.framework.TestCase;

import org.junit.Test;

/**
 * TestCase for {@link LRUCache}.
 * 
 * @author Nils Christian Ehmke
 * @version 1.0
 */
public class LRUCacheTest extends TestCase {

	/**
	 * Creates a new instance of this class.
	 */
	public LRUCacheTest() {}

	@Test
	public void testEntryStorage() {
		final int n = 5;
		final LRUCache<Integer, Integer> cache = new LRUCache<Integer, Integer>(n);

		// Make sure that there is nothing stored under the given values yet.
		for (int i = 0; i < n; i++) {
			Assert.assertNull(cache.get(i));
		}

		// Store everything
		for (int i = 0; i < n; i++) {
			cache.add(i, n - i);
		}

		// Make sure that the values are still available
		for (int i = 0; i < n; i++) {
			Assert.assertEquals((Integer) (n - i), cache.get(i));
		}

		// Overwrite an entry
		cache.add(0, 0);
		// Make sure that it worked
		Assert.assertEquals((Integer) 0, cache.get(0));
	}

	@Test
	public void testMaximalStorage() {
		final int n = 5;
		final LRUCache<Integer, Integer> cache = new LRUCache<Integer, Integer>(n);

		// Make sure that there is nothing stored under the given values yet.
		for (int i = 0; i < n; i++) {
			Assert.assertNull(cache.get(i));
		}

		// Store everything and exceed the size
		for (int i = 0; i < n + 1; i++) {
			cache.add(i, n - i);
		}

		// Make sure that the values are still available
		for (int i = 1; i < n + 1; i++) {
			Assert.assertEquals((Integer) (n - i), cache.get(i));
		}

		// Make sure that the oldest entry isn't available
		Assert.assertNull(cache.get(0));
	}
}
